.. _APIReferenceArchives:

Archives API Reference
=========================

Module imagedata.archives.abstractarchive
-----------------------------------------
.. automodule:: imagedata.archives.abstractarchive
    :members:

Module imagedata.archives.filesystemarchive
--------------------------------------------
.. automodule:: imagedata.archives.filesystemarchive
    :members:

Module imagedata.archives.zipfilearchive
-----------------------------------------
.. automodule:: imagedata.archives.zipfilearchive
    :members:

